@@ -398,7 +398,10 @@ void file_trans::Synchronize(void)
 		
 		iter_al it1 = itb;
 		while (it1 != ite) if (& (* it1) == tagtab[n1].atmr) break;
-		if (it1 == itb) { cout << "BUG: iterator lost!!!" << endl; exit(EXIT_FAILURE); }
+		if (it1 == itb)
+		{
+			assertion_failed(__FILE__, __LINE__, "iterator lost!");
+		}
 		
 		tagtab[n1].atmr = NULL;
 		tagtab[n1].oba = NULL;
